##  Linking Jira Issues to SAP LeanIX Fact Sheets
Link your fact sheets to relevant Jira issues to add context to the initiatives you’re tracking in Jira. You can use synchronization mappings to automate the data exchange between linked issues and fact sheets.
To link a Jira issue to an SAP LeanIX fact sheet, follow these steps:
  1. Open an existing Jira issue in one of your Jira projects.
  2. In the Glance view, choose the SAP LeanIX fact sheet icon.
  3. Choose Link a Fact Sheet.
  4. Search for the fact sheet that you want to link to the issue and select it. Once the fact sheet is linked, you will see the fact sheet under Linked Fact Sheets in Jira.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756ee167a441014a17ac74cb4a047cc_LowRes.png)
**Tip**
To unlink a fact sheet from an issue, open the Glance view, hover over the fact sheet name, and choose Unlink.
